# CHANGELOG

## v0.7.3

### Non-breaking changes

* Added `status` property to `Rowlinson\Api\Responses\Order\OrderItemResponse`

## v0.7.2

### Non-breaking changes

* Added `quantityDispatched` property to `Rowlinson\Api\Responses\Order\OrderItemResponse`

## v0.7.1

### Non-breaking changes

* Added a new property to product variants - `stockDueDate` - if not null it indicates when new stock is expected for that variant

## v0.7.0

### Breaking changes

* Changed the media response on a product to now be a multi-stage array. Originally this looked like:

```php
[ 'images' => [ [ 'width' => 123, 'height' => '456', 'url' => 'https://...' ] ]
```

Now it is:

```php
[ 'images' => [ 'MAROON' => [ '123x456' => [ 'image/jpeg' => 'https://...', 'image/webp' => 'https://...' ] ] ]
```

This will be available both when searching for products and when viewing a single product.

## v0.6.2

### Non-breaking changes

* Added a new property to product variants - `stockLevel` - indicates the current stock level for that variant

## v0.6.1

### Non-breaking changes

* Added a new method `Rowlinson\Api\BasketClient::addBasketItemsFromOrder()` that matches the `basket/add_order/{orderNumber}` API endpoint that populates the basket with available items from the supplied order.

## v0.6.0

### Breaking changes

* Added a new required parameter - `?string $type` to the `Rowlinson\Api\OrderClient::exportOrders` method to enable generating detailed and summary sales reports, the signature is now `DateTimeImmutable $start, DateTimeImmutable $finish, string $type`

## v0.5.1

### Non-breaking changes

* Added a new method `Rowlinson\Api\OrderClient::exportOrders()` that matches the `orders/export` API endpoint that requests a CSV export of orders from the supplied date range 

## v0.5.0

### Breaking changes

* Added a new required parameter - `?string $orderType` to the `Rowlinson\Api\OrderClient::placeOrder()` method, the signature is now `array $items, ?string $deliveryLocationId, ?DeliveryLocation $newDeliveryLocation, ?string $organisation, ?string $recipientName, ?string $deliveryInstructions, ?string $customerReference, ?string $sourceName, ?string $orderType`
* Added a new required parameter - `?string $orderType` to the `Rowlinson\Api\BasketClient::confirm()` method, the signature is now `?string $deliveryLocationId, ?string $customerReference, ?string $deliveryInstructions, ?array $newDeliveryLocation, ?string $orderType`

### Non-breaking changes

* Created a new method `Rowlinson\Api\OrderClient::getOrderTypes()` that matches the `orders/types` API endpoint which returns the forward order types available for the currently authenticated user, or if the authenticated user is an admin, they can pass `all` and see all order types
* Created a new method `Rowlinson\Api\OrderClient::updateOrderType()` that matches the `orders/types/{orderType}` API endpoint which allows admin users to update the customer visibility, due date, cut-off time and how many working days production takes for order types

## v0.4.2

### Non-breaking changes

* Added a new optional parameter - `?bool $approvedVariants` to the `Rowlinson\Api\ProductClient::getProduct()` method for fetching only approved or unapproved variants, `null` will return both - the old and default behaviour

## v0.4.1

### Breaking changes

* Added a new required parameter - `?string $sourceName` to the `Rowlinson\Api\OrderClient::placeOrder()` method, the signature is now `array $items, ?string $deliveryLocationId, ?DeliveryLocation $newDeliveryLocation, ?string $organisation, ?string $recipientName, ?string $deliveryInstructions, ?string $customerReference, ?string $sourceName`
* Added a new required parameter - `?string $sourceName` to the `Rowlinson\Api\Requests\Order\PlaceOrderRequest` method, the signature is now `array $items, ?string $deliveryLocationId, ?DeliveryLocation $newDeliveryLocation, ?string $organisation, ?string $recipientName, ?string $deliveryInstructions, ?string $customerReference, ?string $sourceName`

## v0.4

### Breaking changes

* Moved and renamed current method `Rowlinson\Api\OrderClient::placeOrder()` to `Rowlinson\Api\BasketClient::confirm()` to correctly match its API category + function
* Created a new method `Rowlinson\Api\OrderClient::placeOrder()` that matches the `orders/place` API endpoint which places an order using passed values rather than the current basket

All classes within the `Rowlinson\Api\Requests` namespace are marked as `@internal` so you shouldn't be using these classes in your own code, however:

* Moved and renamed current class `Rowlinson\Api\Requests\Order\PlaceOrderRequest` to `Rowlinson\Api\Requests\Basket\ConfirmRequest` to match the method move
* Created a new class `Rowlinson\Api\Requests\Order\PlaceOrderRequest` to be used with the new `placeOrder` method,

### Non-breaking changes

* Added a new class `Rowlinson\Api\Requests\Order\DeliveryLocation` for new Delivery locations when placing an order, this is not marked as `@internal` and should be used in consumer code
* Added a new class `Rowlinson\Api\Requests\Order\Item` for basket items when placing an order, this is not marked as `@internal`

## v0.3.3

### Non-breaking changes

* Added an `invoiceAddress` property to `Rowlinson\Api\Responses\Organisation\OrganisationResponse`
* Added a `gln` property to `Rowlinson\Api\Responses\DeliveryLocation\DeliveryLocationResponse`

## v0.3.2

### Non-breaking changes

* Added a new method Rowlinson\Api\OrganisationClient::getContacts which will retrieve the contacts for an organisation (admin role users only)
* Added a new response class Rowlinson\Api\Responses\Organisation\ContactResponse for an organisation's contacts

## v0.3.1

### Non-breaking changes

* Rowlinson\Api\BasketClient::validate now correctly catches the 400 (Bad Request) response code that the API returns if the basket under validation has errors, before an exception would have been thrown

## v0.3

### Breaking changes

* Removed the `vatRate` property from `Rowlinson\Api\Responses\Product\ProductVariantResponse`, this property is now called `tax`

### Non-breaking changes

* Added `skuAlias`, `sortCode` and `totalPrice` properties to `Rowlinson\Api\Responses\Product\ProductVariantResponse`

## v0.2.1

### Non-breaking changes

* Added a new parameter to `Rowlinson\Api\ProductClient::getProducts()`, the method signature is now `int $page = 1, ?string $categoryId = null, array $skus = [], array $types = [], bool $includeVariants = false, ?string $organisationAlias = null`, this allows passing an organisation alias that will return that organisation's products if the authenticated user is an admin
* Added a new parameter to `Rowlinson\Api\ProductClient::getProductCount()`, the method signature is now `?string $categoryId = null, array $skus = [], array $types = [], ?string $organisationAlias = null` and allows for the same functionality as `getProducts()` above

## v0.2

### Breaking changes

* Moved the following methods from `Rowlinson\Api\UserClient` to `Rowlinson\Api\AuthClient`:
    - `login`
    - `logout`
    - `verify`
    - `verifyCredentials`
    - `impersonate`
    - `setApiKey`
* Moved the following methods from `Rowlinson\Api\UserClient` to `Rowlinson\Api\InviteClient`:
    - `invite`
    - `getInvite`
    - `resendInvite`
* Added a new parameter to `Rowlinson\Api\DeliveryLocationClient::getDeliveryLocations()`, the method signature used to be `int $page = 1, int $perPage = 10`, the new signature is `string $organisation = null, int $page = 1, int $perPage = 10`
* Moved `Rowlinson\Api\Responses\User\LoginResponse` to `Rowlinson\Api\Responses\Auth\LoginResponse`
* Moved `Rowlinson\Api\Responses\User\GetInviteResponse` to `Rowlinson\Api\Responses\Invites\GetInviteResponse`
* Moved `Rowlinson\Api\Requests\User\InviteRequest` to `Rowlinson\Api\Requests\Invite\InviteRequest`
* Moved `Rowlinson\Api\Requests\User\{ImpersonateRequest,LoginRequest,VerifyCredentialsRequest,VerifyRequest}` to `Rowlinson\Api\Requests\Auth` namespace

### Non-breaking changes

* Added a new method `Rowlinson\Api\AuthClient::sso()` to exchange an SSO token for an API key
* Added a new method `Rowlinson\Api\BasketClient::validate()` to send a collection of product variants with an optional organisation alias and receive errors and surcharge warnings back
* Added a new client `Rowlinson\Api\OrganisationClient` for fetching information about organisations, this is fetchable via the `createOrganisation()` method on `Rowlinson\Api\Sdk`
